@@ -1,6 +1,3 @@
-import RSSreader
-import example
-
 name = "test-packaging-rss"
 print("test rss pkg loaded")
 
